Rule

Enum Rule 

pub enum Rule {
Show 36 variants EOI, program, s_expression, special_form, fun, def, defn, tfun, tdef, tdefn, ifb, opvar, list, atom, symbol_type, number, symbol, type, TSTR, TNUM, TBOOL, TLIST, TFUN, operator, add, sub, mul, div, less, more, equal, string, string_char, comment, boolean, WHITESPACE,
}

Variants



EOI

End-of-input



program



s_expression



special_form



fun



def



defn



tfun



tdef



tdefn



ifb



opvar



list



atom



symbol_type



number



symbol



type



TSTR



TNUM



TBOOL



TLIST



TFUN



operator



add



sub



mul



div



less



more



equal



string



string_char



comment



boolean



WHITESPACE

Implementations

Source

impl Rule

pub fn all_rules() -> &'static [Rule]